@@ -76,7 +76,7 @@ from de.setup_project import (
     code_file_version, pev_str, pev_val, project_env_vars)
 
 
-__version__ = '0.2.4'
+__version__ = '0.2.5'
 
 
 # --------------- global constants ------------------------------------------------------------------------------------
@@ -888,7 +888,7 @@ def _check_types_linting_tests(pdv: PdvType):
         os.makedirs(".pylint", exist_ok=True)
         if is_portion and 'CI_PROJECT_ID' in os.environ:
             # gitlab pylint err: de/__init__.py:1:0: F0010: error while code parsing: Unable to load file de/__init__.py
-            _cl(62, f"echo > {namespace_name}/__init__.py")
+            _cl(62, f"touch {namespace_name}/__init__.py")
         out: List[str] = []
         _cl(62, f"pylint --output-format=text --max-line-length={line_len} {ignore_options} {' '.join(args)}",
             _exit_on_err=False, lines_output=out)   # instead of _exit_on_err, put the pylint option --exit-zero
